==> msp-core-2.3.2-sources.jar: main/com/particles/msp/api/MSPConstants.kt <==
package com.particles.msp.api

object MSPConstants {
    const val INIT_PARAM_KEY_PPID = "ppid"
    const val INIT_PARAM_KEY_EMAIL = "email"
    const val INIT_PARAM_KEY_UNITY_APP_KEY = "unity_app_key"
    const val INIT_PARAM_KEY_INMOBI_ACCOUNT_ID = "inmobi_account_id"
    const val INIT_PARAM_KEY_MINTEGRAL_APP_ID = "mintegral_app_id"
    const val INIT_PARAM_KEY_MINTEGRAL_APP_KEY = "mintegral_app_key"
    const val INIT_PARAM_KEY_PUBMATIC_PUBLISHER_ID = "pubmatic_publisher_id"
    const val INIT_PARAM_KEY_PUBMATIC_PROFILE_IDS = "pubmatic_profile_ids"
    const val INIT_PARAM_KEY_MOLOCO_APP_KEY = "moloco_app_key"

    // google ads multi format is enabled by default. this is for explicitly disabling it
    const val AD_REQUEST_CUSTOM_PARAM_KEY_GOOGLE_MULTI_FORMAT = "google_multi_format_enabled"

    const val CUSTOM_PARAM_KEY_USER_ID = "user_id"

    const val GOOGLE_AD_MULTI_CONTENT_URLS = "google_ads_multi_content_urls"
    const val GOOGLE_AD_CONTENT_URL = "google_ad_content_url"

    // true/false. only request nova ads. if set true, there will be no googel query info and
    // facebook buyer id in the bid request.
    const val REQUEST_PARAM_KEY_NOVA_ONLY = "request_nova_only"

    const val CUSTOM_PARAM_KEY_USE_MEDIA_CONTROLLER = "use_controller"
    const val CUSTOM_PARAM_KEY_VIDEO_PLAY_INLINE_ENABLED = "video_play_inline_enabled"
    const val CUSTOM_PARAM_KEY_POPUP_CTA_ENABLED = "popup_cta_enabled"


    /**
     * The install time of the app in epoch time in millisecond.
     */
    const val USER_SIGNAL_APP_INSTALL_TIME = "app_install_time"

    /**
     * If the app is first install.
     *
     * value: "true", "false", "unknown"
     */
    const val USER_SIGNAL_IS_FIRST_INSTALL = "is_first_install"

    /**
     * User id from publish app.
     */
    const val USER_SIGNAL_PPID = "ppid"
}

==> msp-core-2.11.0-sources.jar: main/com/particles/msp/api/MSPConstants.kt <==
package com.particles.msp.api

object MSPConstants {
    const val INIT_PARAM_KEY_PPID = "ppid"
    const val INIT_PARAM_KEY_EMAIL = "email"
    const val INIT_PARAM_KEY_UNITY_APP_KEY = "unity_app_key"
    const val INIT_PARAM_KEY_INMOBI_ACCOUNT_ID = "inmobi_account_id"
    const val INIT_PARAM_KEY_MINTEGRAL_APP_ID = "mintegral_app_id"
    const val INIT_PARAM_KEY_MINTEGRAL_APP_KEY = "mintegral_app_key"
    const val INIT_PARAM_KEY_PUBMATIC_PUBLISHER_ID = "pubmatic_publisher_id"
    const val INIT_PARAM_KEY_PUBMATIC_PROFILE_IDS = "pubmatic_profile_ids"
    const val INIT_PARAM_KEY_MOLOCO_APP_KEY = "moloco_app_key"

    // google ads multi format is enabled by default. this is for explicitly disabling it
    const val AD_REQUEST_CUSTOM_PARAM_KEY_GOOGLE_MULTI_FORMAT = "google_multi_format_enabled"

    const val CUSTOM_PARAM_KEY_USER_ID = "user_id"

    const val GOOGLE_AD_MULTI_CONTENT_URLS = "google_ads_multi_content_urls"
    const val GOOGLE_AD_CONTENT_URL = "google_ad_content_url"

    // true/false. only request nova ads. if set true, there will be no googel query info and
    // facebook buyer id in the bid request.
    const val REQUEST_PARAM_KEY_NOVA_ONLY = "request_nova_only"

    const val CUSTOM_PARAM_KEY_USE_MEDIA_CONTROLLER = "use_controller"
    const val CUSTOM_PARAM_KEY_VIDEO_PLAY_INLINE_ENABLED = "video_play_inline_enabled"
    const val CUSTOM_PARAM_KEY_POPUP_CTA_ENABLED = "popup_cta_enabled"


    /**
     * The install time of the app in epoch time in millisecond.
     */
    const val USER_SIGNAL_APP_INSTALL_TIME = "app_install_time"

    /**
     * If the app is first install.
     *
     * value: "true", "false", "unknown"
     */
    const val USER_SIGNAL_IS_FIRST_INSTALL = "is_first_install"

    /**
     * User id from publish app.
     */
    const val USER_SIGNAL_PPID = "ppid"

    internal const val DEVICE_SIGNAL_BATTERY_LEVEL = "battery_level"
    internal const val DEVICE_SIGNAL_BATTERY_STATUS = "battery_status"
}
